@@ -500,7 +500,7 @@ class Interface(object):
         timeout = 10
         while not self.subscribed:
             if timeout == 0:
-                LOGGER.error('MQTT Send timeout :: {}.'.format(messsage))
+                LOGGER.error('MQTT Send timeout :: {}.'.format(message))
                 return
 
             LOGGER.warning('MQTT Send waiting on connection :: {}'.format(message))
@@ -621,15 +621,30 @@ class Interface(object):
             for key in input:
                 LOGGER.debug('DEQUEING {}'.format(key))
                 if isinstance(input[key], list):
+                    published = {
+                            'notices': self.NOTICES,
+                            'customparams': self.CUSTOMPARAMS,
+                            'customtypedparams': self.CUSTOMTYPEDPARAMS,
+                            'customdata': self.CUSTOMDATA,
+                            'customtypeddata': self.CUSTOMTYPEDDATA,
+                            'idata': None,
+                            'nscustom': self.CUSTOMNS,
+                            }
                     for item in input[key]:
-                        self._handleInput(key, item)
+                        self._handleInput(key, item, published)
+
+                    # We want to also make sure we've published all events?
                     if key == 'getAll':
+                        for k in published:
+                            if published[k] != None:
+                                pub.publish(published[k], None, None)
+
                         pub.publish_wait(self.CONFIGDONE, None)
                 else:
-                    self._handleInput(key, input[key])
+                    self._handleInput(key, input[key], None)
             self.inQueue.task_done()
 
-    def _handleInput(self, key, item):
+    def _handleInput(self, key, item, published):
         #LOGGER.info('PROCESS {} message {} from Polyglot'.format(key, item))
         if key == 'config':
             self._inConfig(item)
@@ -704,24 +719,34 @@ class Interface(object):
                     except:
                         value = item.get('value')
 
+                    k = item.get('key')
+                    published[k] = None
+
+
                     #LOGGER.error('GETALL -> {} {}'.format(item.get('key'), value))
                     if item.get('key') == 'notices':
                         self.Notices.load(value)
                         pub.publish_nt(self.NOTICES, None, value)
+                        published['notices'] = None
                     elif item.get('key') == 'customparams':
                         pub.publish_nt(self.CUSTOMPARAMS, None, value)
+                        published['customparams'] = None
                     elif item.get('key') == 'customtypedparams':
                         pub.publish_nt(self.CUSTOMTYPEDPARAMS, None, value)
+                        published['customtypedparams'] = None
                     elif item.get('key') == 'customdata':
                         pub.publish_nt(self.CUSTOMDATA, None, value)
+                        published['customdata'] = None
                     elif item.get('key') == 'customtypeddata':
                         pub.publish_nt(self.CUSTOMTYPEDDATA, None, value)
+                        published['customtypeddata'] = None
                     elif item.get('key') == 'idata':
                         self._ifaceData.load(value)
                     else:
                         # node server custom key
                         LOGGER.debug('Key {} should be passed to node server.'.format(item.get('key')))
                         pub.publish_nt(self.CUSTOMNS, None, item.get('key'), value)
+                        published['nscustom'] = None
             except ValueError as e:
                 LOGGER.error('Failure trying to load {} data'.format(item.get('key')))
         elif key == 'command':
@@ -869,8 +894,12 @@ class Interface(object):
         """ Returns a copy of the last config received. """
         return self.config
 
-    def db_getNodeDrivers(self, addr):
-        """ Returns a list of nodes that were saved in the database """
+    def db_getNodeDrivers(self, addr = ''):
+        """
+        Returns a list of nodes or a list of drivers that were saved in the
+        database.  If an address is specified, return the drivers for that
+        node, otherwise, return the list of nodes.
+        """
         nl = []
         try:
             if 'nodes' in self.config:
@@ -879,7 +908,7 @@ class Interface(object):
                     if n['address'] == addr:
                         return n['drivers']  # this is an array
             else:
-                LOGGER.error(f'node {addr} not found in config')
+                LOGGER.error(f'No nodes found in config')
         except:
             LOGGER.warning(f'nodeserver config has not yet been recieved.')
 
